@@ -18,28 +18,22 @@ Main usage is easing creating larger test libraries. For more information and
 examples see the project pages at
 https://github.com/robotframework/PythonLibCore
 """
-
 import inspect
 import os
-import sys
+import typing
 
+from robot import __version__ as robot_version
 from robot.utils import PY_VERSION
 
-try:
-    import typing
-except ImportError:
-    typing = None
 
 from robot.api.deco import keyword  # noqa F401
-from robot import __version__ as robot_version
 
-PY2 = sys.version_info < (3,)
-RF31 = robot_version < '3.2'
+RF32 = robot_version < '4.'
 
-__version__ = '2.2.0'
+__version__ = '3.0.0'
 
 
-class HybridCore(object):
+class HybridCore:
 
     def __init__(self, library_components):
         self.keywords = {}
@@ -87,10 +81,7 @@ class HybridCore(object):
                              .format(type(self).__name__, name))
 
     def __dir__(self):
-        if PY2:
-            my_attrs = dir(type(self)) + list(self.__dict__)
-        else:
-            my_attrs = super().__dir__()
+        my_attrs = super().__dir__()
         return sorted(set(my_attrs) | set(self.attributes))
 
     def get_keyword_names(self):
@@ -136,7 +127,7 @@ class DynamicCore(HybridCore):
         path = self.__get_keyword_path(method)
         line_number = self.__get_keyword_line(method)
         if path and line_number:
-            return '%s:%s' % (path, line_number)
+            return '{}:{}'.format(path, line_number)
         if path:
             return path
         if line_number:
@@ -146,7 +137,7 @@ class DynamicCore(HybridCore):
     def __get_keyword_line(self, method):
         try:
             lines, line_number = inspect.getsourcelines(method)
-        except (OSError, IOError, TypeError):
+        except (OSError, TypeError):
             return None
         for increment, line in enumerate(lines):
             if line.strip().startswith('def '):
@@ -160,21 +151,24 @@ class DynamicCore(HybridCore):
             return None
 
 
-class KeywordBuilder(object):
+class KeywordBuilder:
 
     @classmethod
     def build(cls, function):
-        if not PY2:
-            function = inspect.unwrap(function)
         return KeywordSpecification(
             argument_specification=cls._get_arguments(function),
             documentation=inspect.getdoc(function) or '',
             argument_types=cls._get_types(function)
         )
 
+    @classmethod
+    def unwrap(cls, function):
+        return inspect.unwrap(function)
+
     @classmethod
     def _get_arguments(cls, function):
-        arg_spec = cls._get_arg_spec(function)
+        unwrap_function = cls.unwrap(function)
+        arg_spec = cls._get_arg_spec(unwrap_function)
         argument_specification = cls._get_default_and_named_args(
             arg_spec, function
         )
@@ -187,8 +181,6 @@ class KeywordBuilder(object):
 
     @classmethod
     def _get_arg_spec(cls, function):
-        if PY2:
-            return inspect.getargspec(function)
         return inspect.getfullargspec(function)
 
     @classmethod
@@ -199,9 +191,7 @@ class KeywordBuilder(object):
         formated_args = []
         for arg in args:
             if defaults:
-                formated_args.append(
-                    cls._format_defaults(arg, defaults.pop())
-                )
+                formated_args.append((arg, defaults.pop()))
             else:
                 formated_args.append(arg)
         formated_args.reverse()
@@ -219,29 +209,19 @@ class KeywordBuilder(object):
 
     @classmethod
     def _get_kwargs(cls, arg_spec):
-        if PY2:
-            return ['**%s' % arg_spec.keywords] if arg_spec.keywords else []
         return ['**%s' % arg_spec.varkw] if arg_spec.varkw else []
 
     @classmethod
     def _get_kw_only(cls, arg_spec):
         kw_only_args = []
-        if PY2:
-            return kw_only_args
         for arg in arg_spec.kwonlyargs:
             if not arg_spec.kwonlydefaults or arg not in arg_spec.kwonlydefaults:
                 kw_only_args.append(arg)
             else:
                 value = arg_spec.kwonlydefaults.get(arg, '')
-                kw_only_args.append(cls._format_defaults(arg, value))
+                kw_only_args.append((arg, value))
         return kw_only_args
 
-    @classmethod
-    def _format_defaults(cls, arg, value):
-        if RF31:
-            return '%s=%s' % (arg, value)
-        return arg, value
-
     @classmethod
     def _get_types(cls, function):
         if function is None:
@@ -253,8 +233,7 @@ class KeywordBuilder(object):
 
     @classmethod
     def _get_typing_hints(cls, function):
-        if PY2:
-            return {}
+        function = cls.unwrap(function)
         try:
             hints = typing.get_type_hints(function)
         except Exception:
@@ -265,8 +244,10 @@ class KeywordBuilder(object):
             # remove return and self statements
             if arg_with_hint not in all_args:
                 hints.pop(arg_with_hint)
-        default = cls._get_defaults(arg_spec)
-        return cls._remove_optional_none_type_hints(hints, default)
+        if RF32:
+            default = cls._get_defaults(arg_spec)
+            return cls._remove_optional_none_type_hints(hints, default)
+        return hints
 
     @classmethod
     def _args_as_list(cls, function, arg_spec):
@@ -279,6 +260,7 @@ class KeywordBuilder(object):
             function_args.append(arg_spec.varkw)
         return function_args
 
+    # TODO: Remove when support RF 3.2 is dropped
     # Copied from: robot.running.arguments.argumentparser
     @classmethod
     def _remove_optional_none_type_hints(cls, type_hints, defaults):
@@ -293,6 +275,7 @@ class KeywordBuilder(object):
                         type_hints[arg] = types[0]
         return type_hints
 
+    # TODO: Remove when support RF 3.2 is dropped
     # Copied from: robot.running.arguments.argumentparser
     @classmethod
     def _is_union(cls, typing_type):
@@ -308,7 +291,7 @@ class KeywordBuilder(object):
         return zip(names, arg_spec.defaults)
 
 
-class KeywordSpecification(object):
+class KeywordSpecification:
 
     def __init__(self, argument_specification=None, documentation=None, argument_types=None):
         self.argument_specification = argument_specification
